.. :changelog:

History
-------

0.1.4 (2013-09-17)
++++++++++++++++++

* Faster pair generation
* Switch to gromacs 4.6.3-double for tests
* Fixed a bug for multi-chain systems

0.1.3 (2013-09-16)
++++++++++++++++++

* The conversion part wa rewritten to make it more flexible.
* Cholestrol test is now passed.


0.1.2 (2013-09-15)
++++++++++++++++++

* NBFIX section is now parsed. So the results for molecules with NBFIX parameters
such as cholesterol, match better between NAMD and GROMACS.


0.1.1 (2013-09-02)
++++++++++++++++++

* Updates to Readme and License.

0.1.0 (2013-08-25)
++++++++++++++++++

* First release on PyPI.
